@@ -12,7 +12,7 @@ if [ ! -f  ./mergeSkel$ARCH ]; then
     echo "binary mergeSkel$ARCH is not made"
     exit
 fi
-source ./setupenv.sh
+source ./setupenv.sh $0
 #*************
 name="Skeleton"
 #*************
@@ -23,24 +23,24 @@ if [ ! -d $dir ]; then
 fi
 
 shift
-num=`echo $1 | awk '{printf("%3.3d",$1)}'`
+num=`echo $1 | awk '{printf("%4.4d",$1)}'`
 if [ ! -f $dir/$name$num ]; then
     echo " $dir/$name$num  is non existent file"
     exit
 fi
-cp $dir/$name$num  Skeleton
-echo " $dir/$name$num is copied to  Skeleton"
+cp $dir/$name$num  ./Skeleton
+echo " $dir/$name$num is copied to  ./Skeleton"
 shift
 until [ $# -eq 0 ]
 do
-    num=`echo $1 | awk '{printf("%3.3d",$1)}'`
+    num=`echo $1 | awk '{printf("%4.4d",$1)}'`
     if [ ! -f $dir/$name$num ]; then
 	echo " $dir/$name$num is non existent file"
 	exit
     fi
-    echo "making  tempskel from Skeleton +  $dir/$name$num "
+    echo "making  tempskel from ./Skeleton +  $dir/$name$num "
     echo "Skeleton  $dir/$name$num" | ./mergeSkel$ARCH
-    echo "mv tempskel to Skeleton"
+    echo "mv tempskel to ./Skeleton"
     mv ./tempskel  ./Skeleton
     shift
 done
