@@ -288,12 +288,22 @@ c           will  not come here
       if(ThinSampling) then
 c           thin sampling
          if(EthinRatio(1) .lt. 0.) then
-            Ethin(1) = -EthinRatio(1)
-            Ethin(2) = abs(EthinRatio(2))
+            Ethin(1) = abs(EthinRatio(1))
          else
             Ethin(1) = EthinRatio(1)*ergpn
-            Ethin(2) = EthinRatio(2)*ergpn
          endif
+c         if(EthinRatio(2) .lt. 0.) then
+c            Ethin(2) = abs(EthinRatio(2))
+c         else
+c            Ethin(2) = EthinRatio(2)*ergpn
+c         endif
+c             maximum weight above which no thinning
+          Ethin(2) =  EthinRatio(2)
+c///////////////////
+c          write(0, *) ' ****** Ethin1,2=', Ethin
+c          write(0, *) ' ergpn=', ergpn, ' EthinRatio=',EthinRatio
+c////////////////
+
       else
            Ethin(1) = 0.
            Ethin(2) = 0.
