@@ -7,6 +7,39 @@ c                             AlmostVacT, if Reverse=0 and height >AlmostVacH
 c                             0. if Reverse = 1.
 c                             0. if Reverse = 2 and  height > AlmostVacH
 c                                  
+c   A)   if a charged ptcl
+c    A-1) compute (radius of gyro circle)/LamorDiv
+c      where LamorDiv is 10 in default. Also compute length where
+c      dB < 1%. Take minimum of both. 
+c    A-2)   if not Reverse mode,  compute maximum gramage where cascade
+c           scatteing remains very small; For a high energy electron,
+c           density change must be kept small so get minimum of 
+c           of the both gramage.  Convert the gramage into length.
+c           if A-1) is shorter than A-2, take A-1 length and compute
+c           corresponding gramage.  If A-2 is shorter,  leng and thick
+c           are already obtained.
+c    A-3)   if Reverse mode =1,  take A-1) and make thick = 0
+c           if Reverse mode =other, take A-1) and compute thick 
+c           corresponding to A-1)
+c  elsse if
+c   B)   a neutral particle, 
+c     B-1) assume a  large length; rmg
+c          If not Revesr mode, 
+c            for neutrinos use such B-1) and corresponding thickness
+c            (thickness is not used at all)
+c            for photons, 
+c                 if E> mag pair region, get length wherer dB<1 %
+c                 and take min of this and rmg. (gramage not yet computed)
+c            
+c                 if E > LPM region, get gramage where LPM xsection
+c                     remains const
+c                 else  take gramage= X0*5
+c                 compute  corresponding length
+c                 if its rmg< length, use rmg and compute corresponding
+c                 thickness else use already computed length and thick
+c         if Reverse mode = 1, use leng=rmg and thick=0
+c         if Reverse mode =other, use leng =rmg and corresponding thickness
+c
 c
 c
       implicit none
@@ -27,30 +60,50 @@ c
       erg = TrackBefMove.p.fm.p(4)
 c             fix energy dependent truncation path
       if(TrackBefMove.p.charge .ne. 0) then
-
-c            magnetic
+c            magnetic deflection
          call cmagDefR(TrackBefMove, Mag,  rmg)  ! get radius approx.
+c/////////
+c         write(0,*) ' rmg', rmg, ' for E=',erg, ' /LamorDiv=',
+c     *     rmg/LamorDiv
+c/////////
          rmg = rmg/LamorDiv        !  this is almost streight movable
-c            get max length within which B is almost const
-c            length within which dB  < 1 %.
+c            get max length within which B is almost const (dB< 1 %)
          call clengSmallBC(TrackBefMove, rmgmax)  
+c//////////
+c         write(0,*) ' dB < 1% is', rmgmax, ' rmg',rmg
+c/////////////
          rmg = min(rmg, rmgmax)
 c            mul. scatt and lpm
          if(Reverse .eq. 0) then
+c               scattering effect; streight and scattered line must be
+c               not so much different ; path < ztrunc (kg/m2)
             call cmaxCasLen(TrackBefMove, ztrunc)
-            if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
-     *         .and. LpmEffect) then
+c/////////
+c            write(0,*)  ' ztrunc=', ztrunc
+c/////////////
+            if(TrackBefMove.p.code .eq. kelec .and. 
+     *         TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
+     *         .and. LpmEffect ) then
                ztrunc =
      *         max( min(TrackBefMove.pos.depth/10., ztrunc), 
      *              30.d0 )
             endif
+
             call cthick2len(TrackBefMove,
      *          ztrunc, leng, thick, jcut)
+c//////////////
+c            write(0,*) ' thick 2 len=', ' ztrunc->leng=', leng, 
+c     *     ' thick =',thick, ' jcut=', jcut, ' rmg=', rmg
+c////////////
 c                 thick may have been changed to shorter one.
             if(rmg .lt. leng) then
+
                thick = clen2thick(TrackBefMove.pos.height,
      *              TrackBefMove.vec.coszenith, rmg)
                leng = rmg
+c////////////////
+c               write(0,*) ' rmg < leng so thick=', thick, ' leng=',leng
+c/////////////
             endif
 cc            else
 cc               thick = AlmostVacT
@@ -103,8 +156,9 @@ c                 thick may have been changed to shorter one.
      *            TrackBefMove.vec.coszenith, rmg)
                   leng = rmg
                else
-                  thick = AlmostVacT   ! not used.
-                  leng = rmg           ! meas very large
+c                 leng and thick are given
+c                  thick = AlmostVacT   ! not used.
+c                  leng = rmg           ! strange
                endif
             endif
          elseif(Reverse .eq. 1) then
