@@ -486,6 +486,11 @@ c
        minlen = Infty + Infty
 c              get vertical height
        h = TrackBefMove.pos.height
+c/////////
+c       write(0,*) 'NumberOf Inte=', NumberOfInte,
+c     * ' height=',h
+c////////
+
        do i = 1, NumberOfInte
          if(.not. IntInfArray(i).decay) then
 c              convert kg/m2 into length
@@ -493,8 +498,19 @@ c              convert kg/m2 into length
      *        IntInfArray(i).thickness .ne. Infty) then
                call cthick2len(TrackBefMove,
      *         IntInfArray(i).thickness, leng, t, jcut) 
+c///////////////
+c               write(0,*) ' i=',i, ' thick=', IntInfArray(i).thickness,
+c     *         ' after thick2len leng=', leng, ' t=', t, ' jcut=', jcut
+c///////////////
+               if( jcut .ne. 0) then
+                  IntInfArray(i).thickness = t
+               endif
+c                  some work around for insufficient accuracy 
                if(leng .le. 0.) then
                   leng = 1.d-3
+                  IntInfArray(ProcessNo).thickness = clen2thick(h, 
+     *              TrackBefMove.vec.coszenith, 
+     *              IntInfArray(ProcessNo).length )
                endif
             else
                leng = Infty
@@ -507,7 +523,6 @@ c              convert kg/m2 into length
             if(jcut .ne. 0) then
                MoveStat = Truncated
             else
-               jcut = 0
                MoveStat = ToInteract
             endif
             ProcessNo = i
@@ -554,6 +569,12 @@ c        an observation depth.
       real*8 leng, thick
 c
       call cmaxMovLen(leng, thick)
+c//////////
+c      write(0,*) ' after maxMovLen, leng=',leng, ' thick=',thick
+c      write(0,*) '  IntInfArray.length=',IntInfArray(ProcessNo).length
+c      write(0,*) ' procno=', ProcessNo, ' process=', 
+c     *   IntInfArray(ProcessNo).process
+c//////////
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
